@@ -508,15 +508,19 @@ class TestSpecifier:
 
         if expected:
             # Test that the plain string form works
+            assert version in spec
             assert spec.contains(version)
 
             # Test that the version instance form works
+            assert Version(version) in spec
             assert spec.contains(Version(version))
         else:
             # Test that the plain string form works
+            assert version not in spec
             assert not spec.contains(version)
 
             # Test that the version instance form works
+            assert Version(version) not in spec
             assert not spec.contains(Version(version))
 
     @pytest.mark.parametrize(
@@ -528,6 +532,7 @@ class TestSpecifier:
             ("1.0", "===1.0", True),
             ("nope", "===lolwat", False),
             ("1.0.0", "===1.0", False),
+            ("1.0.dev0", "===1.0.dev0", True),
         ],
     )
     def test_specifiers_identity(self, version, spec, expected):
@@ -535,10 +540,10 @@ class TestSpecifier:
 
         if expected:
             # Identity comparisons only support the plain string form
-            assert spec.contains(version)
+            assert version in spec
         else:
             # Identity comparisons only support the plain string form
-            assert not spec.contains(version)
+            assert version not in spec
 
     @pytest.mark.parametrize(
         ("specifier", "expected"),
@@ -576,13 +581,13 @@ class TestSpecifier:
         spec = Specifier(specifier)
 
         if expected:
-            assert spec.contains(version)
+            assert version in spec
             spec.prereleases = False
-            assert not spec.contains(version)
+            assert version not in spec
         else:
-            assert not spec.contains(version)
+            assert version not in spec
             spec.prereleases = True
-            assert spec.contains(version)
+            assert version in spec
 
     @pytest.mark.parametrize(
         ("specifier", "prereleases", "input", "expected"),
@@ -601,8 +606,74 @@ class TestSpecifier:
 
         assert list(spec.filter(input, **kwargs)) == expected
 
-    def test_specifier_explicit_leacy(self):
-        Specifier("==1.0").contains(LegacyVersion("1.0"))
+    @pytest.mark.xfail
+    def test_specifier_explicit_legacy(self):
+        assert Specifier("==1.0").contains(LegacyVersion("1.0"))
+
+    @pytest.mark.parametrize(
+        ('spec', 'op'),
+        [
+            ('~=2.0', '~='),
+            ('==2.1.*', '=='),
+            ('==2.1.0.3', '=='),
+            ('!=2.2.*', '!='),
+            ('!=2.2.0.5', '!='),
+            ('<=5', '<='),
+            ('>=7.9a1', '>='),
+            ('<1.0.dev1', '<'),
+            ('>2.0.post1', '>'),
+            ('===lolwat', '==='),
+        ]
+    )
+    def test_specifier_operator_property(self, spec, op):
+        assert Specifier(spec).operator == op
+
+    @pytest.mark.parametrize(
+        ('spec', 'version'),
+        [
+            ('~=2.0', '2.0'),
+            ('==2.1.*', '2.1.*'),
+            ('==2.1.0.3', '2.1.0.3'),
+            ('!=2.2.*', '2.2.*'),
+            ('!=2.2.0.5', '2.2.0.5'),
+            ('<=5', '5'),
+            ('>=7.9a1', '7.9a1'),
+            ('<1.0.dev1', '1.0.dev1'),
+            ('>2.0.post1', '2.0.post1'),
+            ('===lolwat', 'lolwat'),
+        ]
+    )
+    def test_specifier_version_property(self, spec, version):
+        assert Specifier(spec).version == version
+
+    @pytest.mark.parametrize(
+        ("spec", "expected_length"),
+        [
+            ("", 0),
+            ("==2.0", 1),
+            (">=2.0", 1),
+            (">=2.0,<3", 2),
+            (">=2.0,<3,==2.4", 3),
+        ],
+    )
+    def test_length(self, spec, expected_length):
+        spec = SpecifierSet(spec)
+        assert len(spec) == expected_length
+
+    @pytest.mark.parametrize(
+        ("spec", "expected_items"),
+        [
+            ("", []),
+            ("==2.0", ["==2.0"]),
+            (">=2.0", [">=2.0"]),
+            (">=2.0,<3", [">=2.0", "<3"]),
+            (">=2.0,<3,==2.4", [">=2.0", "<3", "==2.4"]),
+        ],
+    )
+    def test_iteration(self, spec, expected_items):
+        spec = SpecifierSet(spec)
+        items = set(str(item) for item in spec)
+        assert items == set(expected_items)
 
 
 class TestLegacySpecifier:
@@ -707,15 +778,19 @@ class TestLegacySpecifier:
 
         if expected:
             # Test that the plain string form works
+            assert version in spec
             assert spec.contains(version)
 
             # Test that the version instance form works
+            assert LegacyVersion(version) in spec
             assert spec.contains(LegacyVersion(version))
         else:
             # Test that the plain string form works
+            assert version not in spec
             assert not spec.contains(version)
 
             # Test that the version instance form works
+            assert LegacyVersion(version) not in spec
             assert not spec.contains(LegacyVersion(version))
 
     def test_specifier_explicit_prereleases(self):
@@ -749,31 +824,50 @@ class TestSpecifierSet:
     def test_empty_specifier(self, version):
         spec = SpecifierSet(prereleases=True)
 
+        assert version in spec
         assert spec.contains(version)
+        assert parse(version) in spec
         assert spec.contains(parse(version))
 
     def test_specifier_prereleases_explicit(self):
         spec = SpecifierSet()
         assert not spec.prereleases
+        assert "1.0.dev1" not in spec
         assert not spec.contains("1.0.dev1")
         spec.prereleases = True
         assert spec.prereleases
+        assert "1.0.dev1" in spec
         assert spec.contains("1.0.dev1")
 
         spec = SpecifierSet(prereleases=True)
         assert spec.prereleases
+        assert "1.0.dev1" in spec
         assert spec.contains("1.0.dev1")
         spec.prereleases = False
         assert not spec.prereleases
+        assert "1.0.dev1" not in spec
         assert not spec.contains("1.0.dev1")
 
         spec = SpecifierSet(prereleases=True)
         assert spec.prereleases
+        assert "1.0.dev1" in spec
         assert spec.contains("1.0.dev1")
         spec.prereleases = None
         assert not spec.prereleases
+        assert "1.0.dev1" not in spec
         assert not spec.contains("1.0.dev1")
 
+    def test_specifier_contains_prereleases(self):
+        spec = SpecifierSet()
+        assert spec.prereleases is None
+        assert not spec.contains("1.0.dev1")
+        assert spec.contains("1.0.dev1", prereleases=True)
+
+        spec = SpecifierSet(prereleases=True)
+        assert spec.prereleases
+        assert spec.contains("1.0.dev1")
+        assert not spec.contains("1.0.dev1", prereleases=False)
+
     @pytest.mark.parametrize(
         (
             "specifier", "specifier_prereleases", "prereleases", "input",
@@ -816,7 +910,7 @@ class TestSpecifierSet:
 
     def test_legacy_specifiers_combined(self):
         spec = SpecifierSet("<3,>1-1-1")
-        assert spec.contains("2.0")
+        assert "2.0" in spec
 
     @pytest.mark.parametrize(
         ("specifier", "expected"),
