@@ -41,7 +41,7 @@ VERSIONS = [
     "1.0b2-346", "1.0c1.dev456", "1.0c1", "1.0rc2", "1.0c3", "1.0",
     "1.0.post456.dev34", "1.0.post456", "1.1.dev1", "1.2+123abc",
     "1.2+123abc456", "1.2+abc", "1.2+abc123", "1.2+abc123def", "1.2+1234.abc",
-    "1.2+123456",
+    "1.2+123456", "1.2.r32+123456", "1.2.rev33+123456",
 
     # Explicit epoch of 1
     "1!1.0.dev456", "1!1.0a1", "1!1.0a2.dev456", "1!1.0a12.dev456", "1!1.0a12",
@@ -49,7 +49,8 @@ VERSIONS = [
     "1!1.0b2-346", "1!1.0c1.dev456", "1!1.0c1", "1!1.0rc2", "1!1.0c3", "1!1.0",
     "1!1.0.post456.dev34", "1!1.0.post456", "1!1.1.dev1", "1!1.2+123abc",
     "1!1.2+123abc456", "1!1.2+abc", "1!1.2+abc123", "1!1.2+abc123def",
-    "1!1.2+1234.abc", "1!1.2+123456",
+    "1!1.2+1234.abc", "1!1.2+123456", "1!1.2.r32+123456", "1!1.2.rev33+123456",
+
 ]
 
 
@@ -172,10 +173,16 @@ class TestVersion:
             ("1.0.POST", "1.0.post0"),
             ("1.0POST1", "1.0.post1"),
             ("1.0POST", "1.0.post0"),
+            ("1.0r", "1.0.post0"),
+            ("1.0rev", "1.0.post0"),
             ("1.0.POST1", "1.0.post1"),
+            ("1.0.r1", "1.0.post1"),
+            ("1.0.rev1", "1.0.post1"),
             ("1.0-POST", "1.0.post0"),
             ("1.0-POST1", "1.0.post1"),
             ("1.0-5", "1.0.post5"),
+            ("1.0-r5", "1.0.post5"),
+            ("1.0-rev5", "1.0.post5"),
 
             # Local version case insensitivity
             ("1.0+AbC", "1.0+abc"),
